@@ -89,16 +89,19 @@ FBUFFER         stdin_buffer =
 /* GLOBAL scratch strings */
 char            _grTempString[_grTempStringLEN];
 char            _grTempString2[_grTempStringLEN];
+
+// Missing values
+bool	_grMissingValueUsed = true;
+double	_grMissingValue = 1.0e22, _grMissingValue_tolerance = 1.0e20;
+
 double
-_grCmPerUser_y,	/* y cm-on-page / user-unit */
+	_grCmPerUser_y,	/* y cm-on-page / user-unit */
 	_grCmPerUser_x,	/* x cm-on-page / user-unit */
 	_grCurrentPoint_x,	/* current x coordinate of pen */
 	_grCurrentPoint_y,	/* current y coordinate of pen */
 	_grGrayScreenQuantum = .0625,	/* gray step on mac */
 	_grMagx = 1.0,	/* x magnification on screen */
 	_grMagy = 1.0,	/* y magnification on screen */
-	_grMissingValue = 1.0e22,	/* missing value */
-	_grMissingValue_tolerance = 1.0e20,	/* tolerance */
 	_grOriginx = 0.0,	/* x origin on screen */
 	_grOriginy = 0.0,	/* y origin on screen */
 	_grPageHeight_cm = 27.94,	/* page height in cm */
@@ -531,22 +534,23 @@ gr_draw_arc_cm(bool filled, double xc, double yc, double r, double angle1, doubl
 {
 	extern FILE *_grPS;
 	set_environment();
+	set_ps_color('p');
 	set_line_width_curve();
-
-	if (filled) { 
-		fprintf(_grPS, "%.1f %.1f m  %.1f %.1f %.1f %.1f %.1f arc fill\n",
-			xc * PT_PER_CM + r * PT_PER_CM, yc * PT_PER_CM,
+	if (filled) { 		// this block corrected by Wolfgang Voegeli, fixing SF bug 930259 
+		fprintf(_grPS, "%.1f %.1f m %.1f %.1f %.1f %.1f %.1f arc fill\n",
+			xc * PT_PER_CM + r * PT_PER_CM * cos(angle1 / DEG_PER_RAD), 
+			yc * PT_PER_CM + r * PT_PER_CM * sin(angle1 / DEG_PER_RAD),
 			xc * PT_PER_CM, yc * PT_PER_CM,
 			r * PT_PER_CM,
 			angle1, angle2);
 	} else {
-		fprintf(_grPS, "%.1f %.1f m  %.1f %.1f %.1f %.1f %.1f arc stroke\n",
-			xc * PT_PER_CM + r * PT_PER_CM, yc * PT_PER_CM,
+		fprintf(_grPS, "%.1f %.1f m %.1f %.1f %.1f %.1f %.1f arc stroke\n",
+			xc * PT_PER_CM + r * PT_PER_CM * cos(angle1 / DEG_PER_RAD), 
+			yc * PT_PER_CM + r * PT_PER_CM * sin(angle1 / DEG_PER_RAD),
 			xc * PT_PER_CM, yc * PT_PER_CM,
 			r * PT_PER_CM,
 			angle1, angle2);
 	}
-
 	double lw = _griState.linewidth_line() / 2.0 / PT_PER_CM;
 	rectangle bbox(xc - r - lw, yc - r - lw,
 		       xc + r + lw, yc + r + lw);
@@ -1007,15 +1011,19 @@ gr_hsv2rgb(double h, double s, double v, double *r, double *g, double *b)
 bool
 gr_missing(double x)
 {
-	if (_grMissingValue == 0.0)	// ignore tolerance if 0
-		return (x == 0.0);
-	if (x == _grMissingValue)	// speed up (?)
-		return true;
-	x = GRI_ABS(x - _grMissingValue);
-	if (x < _grMissingValue_tolerance)
-		return true;
-	else
+	if (_grMissingValueUsed) {
+		if (_grMissingValue == 0.0)	// ignore tolerance if 0
+			return (x == 0.0);
+		if (x == _grMissingValue)	// speed up (?)
+			return true;
+		x = GRI_ABS(x - _grMissingValue);
+		if (x < _grMissingValue_tolerance)
+			return true;
+		else
+			return false;
+	} else {
 		return false;
+	}
 }
 
 // Is x-value missing? (Notice the x-transform.)
@@ -1285,16 +1293,23 @@ skip_ps_header(FILE * PSfile)
 		}
 }
 
-/*
- * gr_setmissingvalue(double x) SYNOPSIS void	gr_setmissingvalue(double x)
- * DESCRIPTION:  Sets missing value.
- */
-void
-gr_setmissingvalue(double x)
+bool
+gr_using_missing_value()
 {
+	return _grMissingValueUsed;
+}
+void
+gr_set_missing_value(double x)
+{
+	_grMissingValueUsed = true;
 	_grMissingValue = x;
 	_grMissingValue_tolerance = 0.0001 * GRI_ABS(x);
 }
+void
+gr_set_missing_value_none()
+{
+	_grMissingValueUsed = false;
+}
 
 /*
  * gr_setxaxisstyle(int xstyle) Set style for x axis.  Presently there are no
@@ -1743,10 +1758,17 @@ gr_set_clip_ps_rect(double ll_x_pt, double ll_y_pt, double ur_x_pt, double ur_y_
 		fprintf(_grPS, "S Q %% turn existing clipping off since user forgot to\n");
 		check_psfile();
 	}
-	_clip_ps_xleft = ll_x_pt;
-	_clip_ps_ybottom = ll_y_pt;
-	_clip_ps_xright = ur_x_pt;
-	_clip_ps_ytop = ur_y_pt;
+	_clip_ps_xleft = SMALLER_ONE(ll_x_pt, ur_x_pt);
+	_clip_ps_ybottom = SMALLER_ONE(ll_y_pt, ur_y_pt);
+	_clip_ps_xright = LARGER_ONE(ll_x_pt, ur_x_pt);
+	_clip_ps_ytop = LARGER_ONE(ll_y_pt, ur_y_pt);
+
+/*DEK*/	printf("DEBUG: am setting clip to xl=%f  xr=%f  yb=%f  yt=%f\n", _clip_ps_xleft, _clip_ps_xright, _clip_ps_ybottom, _clip_ps_ytop);
+
+/*DEK*/
+// why do I not have "Q" to finish it off?
+// why do I not have "W*" to finish it off?
+/*DEK*/
 	fprintf(_grPS, "q n\n");
 	fprintf(_grPS, "%f %f moveto\n", _clip_ps_xleft, _clip_ps_ybottom);
 	fprintf(_grPS, "%f %f lineto\n", _clip_ps_xright, _clip_ps_ybottom);
