@@ -2167,15 +2167,15 @@ lapse_rate(double S, double t, double p)
 char*
 tmp_file_name()
 {
-	char *rval;
 #if defined(HAVE_TEMPNAM)
-	rval = tempnam("/usr/tmp", "gri");
-	if (rval == NULL) 
+	//	rval = tempnam("/usr/tmp", "gri");
+	char *rval = tempnam(NULL, "gri");
+	if (rval == NULL)
 		return NULL;
 	return rval;
 #else
 #if defined(HAVE_TMPNAM)
-	rval = tmpnam(NULL);
+	char *rval = tmpnam(NULL);
 	if (rval == NULL)
 		return NULL;
 	return rval;
@@ -2456,3 +2456,10 @@ assign_to_column(int index, double value, const char* c)
 		ASSIGN_TO_COLUMN(index, value, _colWEIGHT);
 	return true;
 }
+
+double
+gr_page_height_pt()
+{
+	extern rectangle _page_size;
+	return (_page_size.ury() * PT_PER_CM);
+}
